pub struct AuthInfo {
pub username: Option<String>,
pub password: Option<SecretString>,
pub token: Option<SecretString>,
pub token_file: Option<String>,
pub client_certificate: Option<String>,
pub client_certificate_data: Option<String>,
pub client_key: Option<String>,
pub client_key_data: Option<SecretString>,
pub impersonate: Option<String>,
pub impersonate_groups: Option<Vec<String>>,
pub auth_provider: Option<AuthProviderConfig>,
pub exec: Option<ExecConfig>,
}Expand description
AuthInfo stores information to tell cluster who you are.
Fields
username: Option<String>The username for basic authentication to the kubernetes cluster.
password: Option<SecretString>The password for basic authentication to the kubernetes cluster.
token: Option<SecretString>The bearer token for authentication to the kubernetes cluster.
token_file: Option<String>Pointer to a file that contains a bearer token (as described above). If both token and token_fileare present,token` takes precedence.
client_certificate: Option<String>Path to a client cert file for TLS.
client_certificate_data: Option<String>PEM-encoded data from a client cert file for TLS. Overrides client_certificate
this key should be base64 encoded instead of the decode string data
client_key: Option<String>Path to a client key file for TLS.
client_key_data: Option<SecretString>PEM-encoded data from a client key file for TLS. Overrides client_key
this key should be base64 encoded instead of the decode string data
impersonate: Option<String>The username to act-as.
impersonate_groups: Option<Vec<String>>The groups to imperonate.
auth_provider: Option<AuthProviderConfig>Specifies a custom authentication plugin for the kubernetes cluster.
exec: Option<ExecConfig>Specifies a custom exec-based authentication plugin for the kubernetes cluster.